/* merriweather-latin-300-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 300;
  src: url(./files/merriweather-latin-300-italic.woff2) format('woff2'), url(./files/merriweather-latin-300-italic.woff) format('woff');
}

/* merriweather-latin-400-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 400;
  src: url(./files/merriweather-latin-400-italic.woff2) format('woff2'), url(./files/merriweather-latin-400-italic.woff) format('woff');
}

/* merriweather-latin-500-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 500;
  src: url(./files/merriweather-latin-500-italic.woff2) format('woff2'), url(./files/merriweather-latin-500-italic.woff) format('woff');
}

/* merriweather-latin-600-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 600;
  src: url(./files/merriweather-latin-600-italic.woff2) format('woff2'), url(./files/merriweather-latin-600-italic.woff) format('woff');
}

/* merriweather-latin-700-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 700;
  src: url(./files/merriweather-latin-700-italic.woff2) format('woff2'), url(./files/merriweather-latin-700-italic.woff) format('woff');
}

/* merriweather-latin-800-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 800;
  src: url(./files/merriweather-latin-800-italic.woff2) format('woff2'), url(./files/merriweather-latin-800-italic.woff) format('woff');
}

/* merriweather-latin-900-italic */
@font-face {
  font-family: 'Merriweather';
  font-style: italic;
  font-display: swap;
  font-weight: 900;
  src: url(./files/merriweather-latin-900-italic.woff2) format('woff2'), url(./files/merriweather-latin-900-italic.woff) format('woff');
}